@@ -217,6 +217,22 @@ QUESTION_TYPE_DICT = \
             "type": "geopoint"
         }
     }, 
+    "q geoshape": {
+        "control": {
+            "tag": "input"
+        }, 
+        "bind": {
+            "type": "geoshape"
+        }
+    }, 
+    "q geotrace": {
+        "control": {
+            "tag": "input"
+        }, 
+        "bind": {
+            "type": "geotrace"
+        }
+    }, 
     "q image": {
         "control": {
             "tag": "upload", 
@@ -342,6 +358,24 @@ QUESTION_TYPE_DICT = \
         }, 
         "hint": "GPS coordinates can only be collected when outside."
     }, 
+    "geoshape": {
+        "control": {
+            "tag": "input"
+        }, 
+        "bind": {
+            "type": "geoshape"
+        }, 
+        "hint": "GPS coordinates can only be collected when outside."
+    }, 
+    "geotrace": {
+        "control": {
+            "tag": "input"
+        }, 
+        "bind": {
+            "type": "geotrace"
+        }, 
+        "hint": "GPS coordinates can only be collected when outside."
+    }, 
     "select multiple from": {
         "control": {
             "tag": "select"
